@@ -1,4 +1,4 @@
-# Copyright (C) 2018-2021  The Software Heritage developers
+# Copyright (C) 2018-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -8,7 +8,6 @@
 from collections import defaultdict
 from typing import Any, Dict, List, Optional, Tuple
 
-from django.core.cache import cache
 from django.shortcuts import render
 from django.utils.html import escape
 
@@ -38,6 +37,7 @@ from swh.web.common.typing import (
     SWHObjectInfo,
 )
 from swh.web.common.utils import (
+    django_cache,
     format_utc_iso_date,
     gen_path_info,
     reverse,
@@ -280,6 +280,7 @@ def process_snapshot_branches(
     return ret_branches, ret_releases, resolved_aliases
 
 
+@django_cache()
 def get_snapshot_content(
     snapshot_id: str,
 ) -> Tuple[List[SnapshotBranchInfo], List[SnapshotReleaseInfo], Dict[str, Any]]:
@@ -303,15 +304,6 @@ def get_snapshot_content(
     Raises:
         NotFoundExc if the snapshot does not exist
     """
-    cache_entry_id = "swh_snapshot_%s" % snapshot_id
-    cache_entry = cache.get(cache_entry_id)
-
-    if cache_entry:
-        return (
-            cache_entry["branches"],
-            cache_entry["releases"],
-            cache_entry.get("aliases", {}),
-        )
 
     branches: List[SnapshotBranchInfo] = []
     releases: List[SnapshotReleaseInfo] = []
@@ -325,10 +317,6 @@ def get_snapshot_content(
         )
         branches, releases, aliases = process_snapshot_branches(snapshot)
 
-    cache.set(
-        cache_entry_id, {"branches": branches, "releases": releases, "aliases": aliases}
-    )
-
     return branches, releases, aliases
 
 
@@ -483,11 +471,11 @@ def get_snapshot_context(
 
     releases = list(reversed(releases))
 
-    snapshot_sizes_cache_id = f"swh_snapshot_{snapshot_id}_sizes"
-    snapshot_sizes = cache.get(snapshot_sizes_cache_id)
-    if snapshot_sizes is None:
-        snapshot_sizes = archive.lookup_snapshot_sizes(snapshot_id)
-        cache.set(snapshot_sizes_cache_id, snapshot_sizes)
+    @django_cache()
+    def _get_snapshot_sizes(snapshot_id):
+        return archive.lookup_snapshot_sizes(snapshot_id)
+
+    snapshot_sizes = _get_snapshot_sizes(snapshot_id)
 
     is_empty = (snapshot_sizes["release"] + snapshot_sizes["revision"]) == 0
 
@@ -622,7 +610,9 @@ def get_snapshot_context(
         release_query_params.pop("revision", None)
         release_query_params["release"] = r["name"]
         r["url"] = reverse(
-            browse_view_name, url_args=url_args, query_params=release_query_params,
+            browse_view_name,
+            url_args=url_args,
+            query_params=release_query_params,
         )
 
     revision_info = None
@@ -723,11 +713,12 @@ def browse_snapshot_directory(
     """
     _check_origin_url(snapshot_id, origin_url)
 
+    visit_id = int(request.GET.get("visit_id", 0))
     snapshot_context = get_snapshot_context(
         snapshot_id=snapshot_id,
         origin_url=origin_url,
         timestamp=timestamp,
-        visit_id=request.GET.get("visit_id"),
+        visit_id=visit_id or None,
         path=path,
         browse_context="directory",
         branch_name=request.GET.get("branch"),
@@ -822,7 +813,12 @@ def browse_snapshot_directory(
         dir_path = "/" + path
 
     swh_objects = []
-    vault_cooking = {}
+    vault_cooking = {
+        "directory_context": False,
+        "directory_swhid": None,
+        "revision_context": False,
+        "revision_swhid": None,
+    }
     revision_found = False
 
     if revision_id is not None:
@@ -838,14 +834,20 @@ def browse_snapshot_directory(
             SWHObjectInfo(object_type=ObjectType.DIRECTORY, object_id=sha1_git)
         )
         vault_cooking.update(
-            {"directory_context": True, "directory_swhid": f"swh:1:dir:{sha1_git}",}
+            {
+                "directory_context": True,
+                "directory_swhid": f"swh:1:dir:{sha1_git}",
+            }
         )
     if revision_id is not None and revision_found:
         swh_objects.append(
             SWHObjectInfo(object_type=ObjectType.REVISION, object_id=revision_id)
         )
         vault_cooking.update(
-            {"revision_context": True, "revision_swhid": f"swh:1:rev:{revision_id}",}
+            {
+                "revision_context": True,
+                "revision_swhid": f"swh:1:rev:{revision_id}",
+            }
         )
     swh_objects.append(
         SWHObjectInfo(object_type=ObjectType.SNAPSHOT, object_id=snapshot_id)
@@ -937,11 +939,12 @@ def browse_snapshot_log(request, snapshot_id=None, origin_url=None, timestamp=No
     """
     _check_origin_url(snapshot_id, origin_url)
 
+    visit_id = int(request.GET.get("visit_id", 0))
     snapshot_context = get_snapshot_context(
         snapshot_id=snapshot_id,
         origin_url=origin_url,
         timestamp=timestamp,
-        visit_id=request.GET.get("visit_id"),
+        visit_id=visit_id or None,
         browse_context="log",
         branch_name=request.GET.get("branch"),
         release_name=request.GET.get("release"),
@@ -1082,11 +1085,12 @@ def browse_snapshot_branches(
     """
     _check_origin_url(snapshot_id, origin_url)
 
+    visit_id = int(request.GET.get("visit_id", 0))
     snapshot_context = get_snapshot_context(
         snapshot_id=snapshot_id,
         origin_url=origin_url,
         timestamp=timestamp,
-        visit_id=request.GET.get("visit_id"),
+        visit_id=visit_id or None,
     )
 
     branches_bc = request.GET.get("branches_breadcrumbs", "")
@@ -1198,11 +1202,12 @@ def browse_snapshot_releases(
     """
     _check_origin_url(snapshot_id, origin_url)
 
+    visit_id = int(request.GET.get("visit_id", 0))
     snapshot_context = get_snapshot_context(
         snapshot_id=snapshot_id,
         origin_url=origin_url,
         timestamp=timestamp,
-        visit_id=request.GET.get("visit_id"),
+        visit_id=visit_id or None,
     )
 
     rel_bc = request.GET.get("releases_breadcrumbs", "")
