@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -6,18 +6,19 @@
 import base64
 import stat
 import textwrap
+from typing import Tuple
 
+import chardet
 import magic
-import sentry_sdk
 
-from django.core.cache import cache
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
 
 from swh.web.common import archive, highlightjs
-from swh.web.common.exc import NotFoundExc
+from swh.web.common.exc import NotFoundExc, sentry_capture_exception
 from swh.web.common.utils import (
     browsers_supported_image_mimes,
+    django_cache,
     format_utc_iso_date,
     reverse,
     rst_to_html,
@@ -25,6 +26,7 @@ from swh.web.common.utils import (
 from swh.web.config import get_config
 
 
+@django_cache()
 def get_directory_entries(sha1_git):
     """Function that retrieves the content of a directory
     from the archive.
@@ -42,12 +44,6 @@ def get_directory_entries(sha1_git):
     Raises:
         NotFoundExc if the directory is not found
     """
-    cache_entry_id = "directory_entries_%s" % sha1_git
-    cache_entry = cache.get(cache_entry_id)
-
-    if cache_entry:
-        return cache_entry
-
     entries = list(archive.lookup_directory(sha1_git))
     for e in entries:
         e["perms"] = stat.filemode(e["perms"])
@@ -62,8 +58,6 @@ def get_directory_entries(sha1_git):
     dirs = sorted(dirs, key=lambda d: d["name"])
     files = sorted(files, key=lambda f: f["name"])
 
-    cache.set(cache_entry_id, (dirs, files))
-
     return dirs, files
 
 
@@ -91,12 +85,30 @@ def get_mimetype_and_encoding_for_content(content):
 content_display_max_size = get_config()["content_display_max_size"]
 
 
-def _re_encode_content(mimetype, encoding, content_data):
-    # encode textual content to utf-8 if needed
-    if mimetype.startswith("text/"):
-        # probably a malformed UTF-8 content, re-encode it
-        # by replacing invalid chars with a substitution one
-        if encoding == "unknown-8bit":
+def re_encode_content(
+    mimetype: str, encoding: str, content_data: bytes
+) -> Tuple[str, str, bytes]:
+    """Try to re-encode textual content if it is not encoded to UTF-8
+    for proper display in the browse Web UI.
+
+    Args:
+        mimetype: content mimetype as detected by python-magic
+        encoding: content encoding as detected by python-magic
+        content_data: raw content bytes
+
+    Returns:
+        A tuple with 3 members: content mimetype, content encoding (possibly updated
+        after processing), content raw bytes (possibly reencoded to UTF-8)
+    """
+    if mimetype.startswith("text/") and encoding not in ("us-ascii", "utf-8"):
+        # first check if chardet detects an encoding with confidence
+        result = chardet.detect(content_data)
+        if result["confidence"] >= 0.9:
+            encoding = result["encoding"]
+            content_data = content_data.decode(encoding).encode("utf-8")
+        elif encoding == "unknown-8bit":
+            # probably a malformed UTF-8 content, re-encode it
+            # by replacing invalid chars with a substitution one
             content_data = content_data.decode("utf-8", "replace").encode("utf-8")
         elif encoding not in ["utf-8", "binary"]:
             content_data = content_data.decode(encoding, "replace").encode("utf-8")
@@ -108,8 +120,8 @@ def _re_encode_content(mimetype, encoding, content_data):
         for enc in encodings:
             try:
                 content_data = content_data.decode(enc).encode("utf-8")
-            except Exception as exc:
-                sentry_sdk.capture_exception(exc)
+            except Exception:
+                pass
             else:
                 # ensure display in content view
                 encoding = enc
@@ -119,7 +131,9 @@ def _re_encode_content(mimetype, encoding, content_data):
 
 
 def request_content(
-    query_string, max_size=content_display_max_size, re_encode=True,
+    query_string,
+    max_size=content_display_max_size,
+    re_encode=True,
 ):
     """Function that retrieves a content from the archive.
 
@@ -151,7 +165,7 @@ def request_content(
         filetype = archive.lookup_content_filetype(query_string)
         language = archive.lookup_content_language(query_string)
     except Exception as exc:
-        sentry_sdk.capture_exception(exc)
+        sentry_capture_exception(exc)
     mimetype = "unknown"
     encoding = "unknown"
     if filetype:
@@ -162,7 +176,7 @@ def request_content(
         try:
             content_raw = archive.lookup_content_raw(query_string)
         except Exception as exc:
-            sentry_sdk.capture_exception(exc)
+            sentry_capture_exception(exc)
             raise NotFoundExc(
                 "The bytes of the content are currently not available "
                 "in the archive."
@@ -176,7 +190,7 @@ def request_content(
                 )
 
             if re_encode:
-                mimetype, encoding, raw_data = _re_encode_content(
+                mimetype, encoding, raw_data = re_encode_content(
                     mimetype, encoding, content_data["raw_data"]
                 )
                 content_data["raw_data"] = raw_data
@@ -697,18 +711,15 @@ def get_readme_to_display(readmes):
     # convert rst README to html server side as there is
     # no viable solution to perform that task client side
     if readme_name and readme_name.endswith(".rst"):
-        cache_entry_id = "readme_%s" % readme_sha1
-        cache_entry = cache.get(cache_entry_id)
 
-        if cache_entry:
-            readme_html = cache_entry
-        else:
-            try:
-                rst_doc = request_content(readme_sha1)
-                readme_html = rst_to_html(rst_doc["raw_data"])
-                cache.set(cache_entry_id, readme_html)
-            except Exception as exc:
-                sentry_sdk.capture_exception(exc)
-                readme_html = "Readme bytes are not available"
+        @django_cache(
+            catch_exception=True,
+            exception_return_value="Readme bytes are not available",
+        )
+        def _rst_readme_to_html(readme_sha1):
+            rst_doc = request_content(readme_sha1)
+            return rst_to_html(rst_doc["raw_data"])
+
+        readme_html = _rst_readme_to_html(readme_sha1)
 
     return readme_name, readme_url, readme_html
