@@ -37,9 +37,9 @@ from swh.storage.interface import Sha1
 from swh.storage.utils import now
 from swh.web import config
 from swh.web.browse.utils import (
-    _re_encode_content,
     get_mimetype_and_encoding_for_content,
     prepare_content_for_display,
+    re_encode_content,
 )
 from swh.web.common import archive
 
@@ -48,20 +48,30 @@ from swh.web.common import archive
 # Base content indexer configuration
 _TEST_INDEXER_BASE_CONFIG = {
     "storage": {"cls": "memory"},
-    "objstorage": {"cls": "memory", "args": {},},
-    "indexer_storage": {"cls": "memory", "args": {},},
+    "objstorage": {
+        "cls": "memory",
+        "args": {},
+    },
+    "indexer_storage": {
+        "cls": "memory",
+        "args": {},
+    },
 }
 
 
-def random_sha1():
-    return hash_to_hex(bytes(random.randint(0, 255) for _ in range(20)))
+def random_sha1_bytes() -> Sha1:
+    return bytes(random.randint(0, 255) for _ in range(20))
 
 
-def random_sha256():
+def random_sha1() -> str:
+    return hash_to_hex(random_sha1_bytes())
+
+
+def random_sha256() -> str:
     return hash_to_hex(bytes(random.randint(0, 255) for _ in range(32)))
 
 
-def random_blake2s256():
+def random_blake2s256() -> str:
     return hash_to_hex(bytes(random.randint(0, 255) for _ in range(32)))
 
 
@@ -93,7 +103,9 @@ _TEST_LICENSE_INDEXER_CONFIG = merge_configs(
         "tools": {
             "name": "nomos",
             "version": "3.1.0rc2-31-ga2cbb8c",
-            "configuration": {"command_line": "nomossa <filepath>",},
+            "configuration": {
+                "command_line": "nomossa <filepath>",
+            },
         },
     },
 )
@@ -252,7 +264,9 @@ def _init_tests_data():
                 os.path.dirname(__file__), "resources/repos/%s" % archive_
             )
             loader = GitLoaderFromArchive(
-                storage, origin["url"], archive_path=origin_repo_archive,
+                storage,
+                origin["url"],
+                archive_path=origin_repo_archive,
             )
 
             result = loader.load()
@@ -407,7 +421,7 @@ def _init_tests_data():
         cnt_data = storage.content_get_data(content.sha1)
         assert cnt_data is not None
         mimetype, encoding = get_mimetype_and_encoding_for_content(cnt_data)
-        _, _, cnt_data = _re_encode_content(mimetype, encoding, cnt_data)
+        _, _, cnt_data = re_encode_content(mimetype, encoding, cnt_data)
 
         content_display_data = prepare_content_for_display(cnt_data, mimetype, path)
 
